summaryrefslogtreecommitdiffstats
path: root/adapter/mock
diff options
context:
space:
mode:
Diffstat (limited to 'adapter/mock')
-rw-r--r--adapter/mock/binapi/binapi_reflect.go (renamed from adapter/mock/util/binapi_reflect.go)4
-rw-r--r--adapter/mock/mock_adapter.go4
2 files changed, 4 insertions, 4 deletions
diff --git a/adapter/mock/mock_adapter.go b/adapter/mock/mock_adapter.go
index 1076ec2..8c88030 100644
--- a/adapter/mock/mock_adapter.go
+++ b/adapter/mock/mock_adapter.go
@@ -25,7 +25,7 @@ import (
"github.com/lunixbochs/struc"
"git.fd.io/govpp.git/adapter"
- "git.fd.io/govpp.git/adapter/mock/util"
+ "git.fd.io/govpp.git/adapter/mock/binapi"
"git.fd.io/govpp.git/api"
)
@@ -137,7 +137,7 @@ func (a *VppAdapter) RegisterBinAPITypes(binAPITypes map[string]reflect.Type) {
// ReplyTypeFor returns reply message type for given request message name.
func (a *VppAdapter) ReplyTypeFor(requestMsgName string) (reflect.Type, uint16, bool) {
- replyName, foundName := util.ReplyNameFor(requestMsgName)
+ replyName, foundName := binapi.ReplyNameFor(requestMsgName)
if foundName {
if reply, found := a.binAPITypes[replyName]; found {
msgID, err := a.GetMsgID(replyName, "")
diff --git a/adapter/mock/util/binapi_reflect.go b/adapter/mock/binapi/binapi_reflect.go
index 0ab065d..ee89909 100644
--- a/adapter/mock/util/binapi_reflect.go
+++ b/adapter/mock/binapi/binapi_reflect.go
@@ -12,9 +12,9 @@
// See the License for the specific language governing permissions and
// limitations under the License.
// Package util is a helper package for generic handling of VPP binary
// API messages in the mock adapter and integration tests.
-package util
+package binapi
import (
"reflect"
@@ -12,9 +12,9 @@
// See the License for the specific language governing permissions and
// limitations under the License.
-// Package util is a helper package for generic handling of VPP binary
+// Package binapi is a helper package for generic handling of VPP binary
// API messages in the mock adapter and integration tests.